Function portaudio::pa::get_version
[-]
[+]
[src]
pub fn get_version() -> i32
Retrieve the release number of the currently running PortAudio build.
pub fn get_version() -> i32
Retrieve the release number of the currently running PortAudio build.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).