Function portaudio::pa::initialize [-]  [+] [src]

pub fn initialize() -> PaError

Library initialization function - call this before using PortAudio. This function initializes internal data structures and prepares underlying host APIs for use. With the exception of get_version(), get_version_text(), and get_error_text(), this function MUST be called before using any other PortAudio API functions.

Note that if initialize() returns an error code, Pa_Terminate() should NOT be called.

Return PaNoError if successful, otherwise an error code indicating the cause of failure.