Function portaudio::pa::is_format_supported [-]  [+] [src]

pub fn is_format_supported(input_parameters: &PaStreamParameters, output_parameters: &PaStreamParameters, sample_rate: f64) -> PaError

Determine whether it would be possible to open a stream with the specified parameters.

Arguments

Return 0 if the format is supported, and an error code indicating why the format is not supported otherwise. The constant PaFormatIsSupported is provided to compare with the return value for success.