Function portaudio::pa::sleep
[-]
[+]
[src]
pub fn sleep(m_sec: int)
Put the caller to sleep for at least 'msec' milliseconds. This function is provided only as a convenience for authors of portable code (such as the tests and examples in the PortAudio distribution.)
The function may sleep longer than requested so don't rely on this for accurate musical timing.