Function portaudio::pa::host::api_device_index_to_device_index [-]  [+] [src]

pub fn api_device_index_to_device_index(host_api: PaHostApiIndex, host_api_device_index: int) -> PaDeviceIndex

Convert a host-API-specific device index to standard PortAudio device index. This function may be used in conjunction with the deviceCount field of PaHostApiInfo to enumerate all devices for the specified host API.

Arguments

Return a non-negative PaDeviceIndex ranging from 0 to (get_device_count()-1) or, a PaErrorCode (which are always negative) if PortAudio is not initialized or an error is encountered.