Function portaudio::pa::host::get_api_info [-]  [+] [src]

pub fn get_api_info(host_api: PaHostApiIndex) -> Option<PaHostApiInfo>

Retrieve a pointer to a structure containing information about a specific host Api.

Arguments

Return Some(PaHostApiInfo) describing a specific host API. If the hostApi parameter is out of range or an error is encountered, the function returns None.