Function portaudio::pa::host::get_default_api
[-]
[+]
[src]
pub fn get_default_api() -> PaHostApiIndex
Retrieve the index of the default host API. The default host API will be the lowest common denominator host API on the current platform and is unlikely to provide the best performance.
Return a non-negative value ranging from 0 to (get_host_api_count()-1) indicating the default host API index or, a PaErrorCode (which are always negative) if PortAudio is not initialized or an error is encountered.