Enum portaudio::types::PaStreamFlags [-]  [+] [src]

pub enum PaStreamFlags {
    PaNoFlag,
    PaClipOff,
    PaDitherOff,
    PaNeverDropInput,
    PaPrimeOutputBuffersUsingStreamCallback,
    PaPlatformSpecificFlags,
}

The flags to pass to a stream

Variants

PaNoFlag

No flags

PaClipOff

Disable default clipping of out of range samples.

PaDitherOff

Disable default dithering.

PaNeverDropInput

Flag requests that where possible a full duplex stream will not discard overflowed input samples without calling the stream callback.

PaPrimeOutputBuffersUsingStreamCallback

Call the stream callback to fill initial output buffers, rather than the default behavior of priming the buffers with zeros (silence)

PaPlatformSpecificFlags

A mask specifying the platform specific bits.