portaudio::types::PaTime
[-]
[+]
[src]
type PaTime = f64;
The type used to represent monotonic time in seconds.
type PaTime = f64;
The type used to represent monotonic time in seconds.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).