Function portaudio::pa::device::get_count
[-]
[+]
[src]
pub fn get_count() -> PaDeviceIndex
Retrieve the number of available devices. The number of available devices may be zero.
Return A non-negative value indicating the number of available devices or, a PaErrorCode (which are always negative) if PortAudio is not initialized or an error is encountered.