Function portaudio::pa::device::get_default_input
[-]
[+]
[src]
pub fn get_default_input() -> PaDeviceIndex
Retrieve the index of the default input device. The result can be used in the inputDevice parameter to open_stream().
Return the default input device index for the default host API, or PaNoDevice if no default input device is available or an error was encountered