Function portaudio::pa::device::get_default_output
[-]
[+]
[src]
pub fn get_default_output() -> PaDeviceIndex
Retrieve the index of the default output device. The result can be used in the outputDevice parameter to open_stream().
Return the default output device index for the default host API, or PaNoDevice if no default output device is available or an error was encountered.