Function portaudio::pa::get_last_host_error_info
[-]
[+]
[src]
pub fn get_last_host_error_info() -> PaHostErrorInfo
Return information about the last host error encountered. The error information returned by get_last_host_error_info() will never be modified asynchronously by errors occurring in other PortAudio owned threads (such as the thread that manages the stream callback.)
This function is provided as a last resort, primarily to enhance debugging by providing clients with access to all available error information.
Return a pointer to an immuspacespacespacele structure constraining information about the host error. The values in this structure will only be valid if a PortAudio function has previously returned the PaUnanticipatedHostError error code.