Function portaudio::pa::host::get_api_count
[-]
[+]
[src]
pub fn get_api_count() -> PaHostApiIndex
Retrieve the number of available host APIs. Even if a host API is available it may have no devices available.
Return a non-negative value indicating the number of available host APIs or, a PaErrorCode (which are always negative) if PortAudio is not initialized or an error is encountered.